@@ -1,4 +1,4 @@
-/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/config_f.h,v 3.0 1991/07/04 21:54:11 christos Exp $ */
+/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/config_f.h,v 3.1 1991/07/15 19:37:24 christos Exp $ */
 /*
  * config_f.h -- configure various defines for tcsh
  *
@@ -117,4 +117,19 @@
  */
 #undef SYSMALLOC
 
+
+/*
+ * RCSID	This defines if we want rcs strings in the binary or not
+ *
+ */
+#if !defined(lint) && !defined(SABER)
+# ifndef __GNUC__
+#  define RCSID(id) static char *rcsid = (id);
+# else
+#  define RCSID(id) static char *rcsid() { return (id); }
+# endif /* !__GNUC__ */
+#else
+# define RCSID(id)	/* Nothing */
+#endif /* !lint && !SABER */
+
 #endif /* _h_config_f */
