@@ -1,4 +1,4 @@
-/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/sh.lex.c,v 3.0 1991/07/04 21:49:28 christos Exp $ */
+/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/sh.lex.c,v 3.2 1991/07/15 19:37:24 christos Exp $ */
 /*
  * sh.lex.c: Lexical analysis into tokens
  */
@@ -35,10 +35,7 @@
  * SUCH DAMAGE.
  */
 #include "config.h"
-#ifndef lint
-static char *rcsid() 
-    { return "$Id: sh.lex.c,v 3.0 1991/07/04 21:49:28 christos Exp $"; }
-#endif
+RCSID("$Id: sh.lex.c,v 3.2 1991/07/15 19:37:24 christos Exp $")
 
 #include "sh.h"
 #include "ed.h"
@@ -628,7 +625,7 @@ static int quesarg;
 
 static void
 getexcl(sc)
-    Char    sc;
+    int    sc;
 {
     register struct wordent *hp, *ip;
     int     left, right, dol;
@@ -1260,7 +1257,7 @@ setexclp(cp)
 
 void
 unreadc(c)
-    Char    c;
+    int    c;
 {
     peekread = c;
 }
@@ -1402,7 +1399,8 @@ reread:
 static int
 bgetc()
 {
-    register int buf, off, c;
+    register int buf, off;
+    int c;
     register int numleft = 0, roomleft;
     extern Char InputBuf[];
     char    tbuf[BUFSIZ + 1];
@@ -1478,32 +1476,32 @@ again:
 	    if (c >= 0)
 		break;
 	    switch (errno) {
-#ifdef FIONBIO
-		static int zero = 0;
-
-#endif				/* FIONBIO */
 #ifdef EWOULDBLOCK
 	    case EWOULDBLOCK:
-#endif				/* EWOULDBLOCK */
+# define TRY_AGAIN
+#endif /* EWOULDBLOCK */
 #if defined(POSIX) && defined(EAGAIN)
-#if defined(EWOULDBLOCK) && EWOULDBLOCK != EAGAIN
+# if defined(EWOULDBLOCK) && EWOULDBLOCK != EAGAIN
 	    case EAGAIN:
-#endif				/* EWOULDBLOCK && EWOULDBLOCK != EAGAIN */
-#endif				/* POSIX && EAGAIN */
-#if defined(F_SETFL) && defined(O_NDELAY)
-		(void) fcntl(SHIN, F_SETFL,
-			     fcntl(SHIN, F_GETFL, 0) & ~O_NDELAY);
-#endif				/* F_SETFL && O_NDELAY */
-#ifdef FIONBIO
-		(void) ioctl(SHIN, FIONBIO, (ioctl_t) & zero);
-#endif				/* FIONBIO */
-#if (defined(F_SETFL) && defined(O_NDELAY)) || defined(FIONBIO)
+#  define TRY_AGAIN
+# endif /* EWOULDBLOCK && EWOULDBLOCK != EAGAIN */
+#endif /* POSIX && EAGAIN */
+#ifdef TRY_AGAIN
+# if defined(F_SETFL) && defined(O_NDELAY)
+		(void) fcntl(SHIN, F_SETFL, fcntl(SHIN,F_GETFL,0) & ~O_NDELAY);
+# endif /* F_SETFL && O_NDELAY */
+# ifdef FIONBIO
 		c = 0;
-#endif				/* (F_SETFL && O_NDELAY) || FIONBIO */
+		(void) ioctl(SHIN, FIONBIO, (ioctl_t) &c);
+# endif	/* FIONBIO */
+# if (defined(F_SETFL) && defined(O_NDELAY)) || defined(FIONBIO)
+		c = 0;
+# endif	/* (F_SETFL && O_NDELAY) || FIONBIO */
 		break;
+#endif /* TRY_AGAIN */
 #ifdef _SEQUENT_
 	    case EBADF:
-#endif				/* _SEQUENT_ */
+#endif	/* _SEQUENT_ */
 	    case EINTR:
 		c = 0;
 		break;
