@@ -1,4 +1,4 @@
-/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/tc.sig.c,v 3.0 1991/07/04 23:34:26 christos Exp $ */
+/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/tc.sig.c,v 3.1 1991/07/15 19:37:24 christos Exp $ */
 /*
  * sh.sig.c: Signal routine emulations
  */
@@ -35,10 +35,7 @@
  * SUCH DAMAGE.
  */
 #include "config.h"
-#ifndef lint
-static char *rcsid() 
-    { return "$Id: tc.sig.c,v 3.0 1991/07/04 23:34:26 christos Exp $"; }
-#endif
+RCSID("$Id: tc.sig.c,v 3.1 1991/07/15 19:37:24 christos Exp $")
 
 #include "sh.h"
 /*
@@ -69,12 +66,57 @@ static char *rcsid()
 #endif /* SVID == 0 */
 
 #ifndef BSDSIGS
-/* libc.a contains these functions in SVID >= 3. */
+
+/* this stack is used to queue signals
+ * we can handle up to MAX_CHLD outstanding children now;
+ */
+#define MAX_CHLD 50
+static struct mysigstack {
+    int     s_w;		/* wait report			 */
+    int     s_errno;		/* errno returned;		 */
+    int     s_pid;		/* pid returned			 */
+}       stk[MAX_CHLD];
+static int stk_ptr = -1;
+
+
 #if SVID < 3 || defined(UNIXPC)
+/* queue child signals
+ */
+static sigret_t
+sig_ch_queue()
+{
+#ifdef JOBDEBUG
+    xprintf("queue SIGCHLD\n");
+    flush();
+#endif /* JOBDEBUG */
+    stk_ptr++;
+    stk[stk_ptr].s_pid = wait(&stk[stk_ptr].s_w);
+    stk[stk_ptr].s_errno = errno;
+    (void) signal(SIGCHLD, sig_ch_queue);
+    /* shut up the compiler */
+    return(0);
+}
+
+/* process all awaiting child signals
+ */
+static sigret_t
+sig_ch_rel()
+{
+    while (stk_ptr > -1)
+	pchild(SIGCHLD);
+#ifdef JOBDEBUG
+    xprintf("signal(SIGCHLD, pchild);\n");
+#endif /* JOBDEBUG */
+    (void) signal(SIGCHLD, pchild);
+    /* shut up the compiler */
+    return(0);
+}
+
+/* libc.a contains these functions in SVID >= 3. */
 sigret_t
 (*sigset(a, b)) ()
     int     a;
-    int     (*b) ();
+    sigret_t  (*b) __P((int));
 {
     return (signal(a, b));
 }
@@ -98,8 +140,6 @@ void
 sighold(what)
     int     what;
 {
-    int     sig_ch_queue();
-
     if (what == SIGCHLD)
 	(void) signal(SIGCHLD, sig_ch_queue);
 }
@@ -113,86 +153,6 @@ sigignore(a)
     (void) signal(a, SIG_IGN);
 }
 
-#endif				/* SVID < 3 || (UNIXPC) */
-
-/* this stack is used to queue signals
- * we can handle up to MAX_CHLD outstanding children now;
- */
-#define MAX_CHLD 50
-static struct mysigstack {
-    int     s_w;		/* wait report			 */
-    int     s_errno;		/* errno returned;		 */
-    int     s_pid;		/* pid returned			 */
-}       stk[MAX_CHLD];
-static int stk_ptr = -1;
-
-
-/* return either awaiting processes or do a wait now
- */
-int
-ourwait(w)
-    int    *w;
-{
-    int     pid;
-
-#ifdef JOBDEBUG
-    xprintf("our wait %d\n", stk_ptr);
-    flush();
-#endif				/* JOBDEBUG */
-
-    if (stk_ptr == -1) {
-	/* stack empty return signal from stack */
-	pid = wait(w);
-#ifdef JOBDEBUG
-	xprintf("signal(SIGCHLD, pchild);\n");
-#endif				/* JOBDEBUG */
-	(void) signal(SIGCHLD, pchild);
-	return (pid);
-    }
-    else {
-	/* return signal from stack */
-	errno = stk[stk_ptr].s_errno;
-	*w = stk[stk_ptr].s_w;
-	stk_ptr--;
-	return (stk[stk_ptr + 1].s_pid);
-    }
-}				/* end ourwait */
-
-/* queue child signals
- *
- */
-static void
-sig_ch_queue()
-{
-#ifdef JOBDEBUG
-    xprintf("queue SIGCHLD\n");
-    flush();
-#endif				/* JOBDEBUG */
-    stk_ptr++;
-    stk[stk_ptr].s_pid = wait(&stk[stk_ptr].s_w);
-    stk[stk_ptr].s_errno = errno;
-    (void) signal(SIGCHLD, sig_ch_queue);
-}
-
-
-
-
-/* process all awaiting child signals
- */
-static void
-sig_ch_rel()
-{
-    while (stk_ptr > -1)
-	pchild(SIGCHLD);
-#ifdef JOBDEBUG
-    xprintf("signal(SIGCHLD, pchild);\n");
-#endif				/* JOBDEBUG */
-    (void) signal(SIGCHLD, pchild);
-}
-
-/* libc.a contains sigpause.o in SVID >= 3. */
-#if SVID < 3 || defined(UNIXPC)
-
 /* atomically release one signal
  */
 void
@@ -215,7 +175,7 @@ sigpause(what)
 
 }
 
-#endif				/* SVID < 3 || (UNIXPC) */
+#endif /* SVID < 3 || (UNIXPC) */
 
 #ifdef SXA
 /*
@@ -238,16 +198,47 @@ sigpause(what)
     }
 }
 
-#endif				/* SXA */
-#endif				/* BSDSIGS */
+#endif /* SXA */
+
+/* return either awaiting processes or do a wait now
+ */
+int
+ourwait(w)
+    int    *w;
+{
+    int     pid;
+
+#ifdef JOBDEBUG
+    xprintf("our wait %d\n", stk_ptr);
+    flush();
+#endif /* JOBDEBUG */
+
+    if (stk_ptr == -1) {
+	/* stack empty return signal from stack */
+	pid = wait(w);
+#ifdef JOBDEBUG
+	xprintf("signal(SIGCHLD, pchild);\n");
+#endif /* JOBDEBUG */
+	(void) signal(SIGCHLD, pchild);
+	return (pid);
+    }
+    else {
+	/* return signal from stack */
+	errno = stk[stk_ptr].s_errno;
+	*w = stk[stk_ptr].s_w;
+	stk_ptr--;
+	return (stk[stk_ptr + 1].s_pid);
+    }
+} /* end ourwait */
+
+#endif /* BSDSIGS */
 
 #ifdef NEEDsignal
 /* turn into bsd signals */
 sigret_t(*
 	 xsignal(s, a)) ()
     int     s;
-
-sigret_t(*a) ();
+    sigret_t (*a) __P((int));
 {
     sigvec_t osv, sv;
 
@@ -381,8 +372,7 @@ bsd_sigpause(mask)
 	    sigaddset(&set, i);
     sigsuspend(&set);
 }
-
-#endif				/* _SEQUENT_ */
+#endif /* _SEQUENT_ */
 
 
 #ifdef SIGSYNCH
@@ -396,5 +386,4 @@ int sno;
 	abort();
     Synch_Cnt++;
 }
-
-#endif				/* SIGSYNCH */
+#endif /* SIGSYNCH */
