@@ -1,4 +1,4 @@
-/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/tw.help.c,v 3.0 1991/07/04 21:49:28 christos Exp $ */
+/* $Header: /home/hyperion/mu/christos/src/sys/tcsh-6.00/RCS/tw.help.c,v 3.1 1991/07/15 19:37:24 christos Exp $ */
 /* tw.help.c: actually look up and print documentation on a file.
  *	      Look down the path for an appropriate file, then print it.
  *	      Note that the printing is NOT PAGED.  This is because the
@@ -38,13 +38,11 @@
  * SUCH DAMAGE.
  */
 #include "config.h"
-#ifndef lint
-static char *rcsid() 
-    { return "$Id: tw.help.c,v 3.0 1991/07/04 21:49:28 christos Exp $"; }
-#endif
+RCSID("$Id: tw.help.c,v 3.1 1991/07/15 19:37:24 christos Exp $")
 
 #include "sh.h"
 #include "tw.h"
+#include "tc.h"
 
 
 static int f = -1;
@@ -144,6 +142,9 @@ static  sigret_t
 cleanf(snum)
 int snum;
 {
+#if (SVID > 0) && (SVID < 3)
+    (void) sigset(SIGINT, cleanf);
+#endif /* SVID > 0 && SVID < 3 */
     if (f != -1)
 	(void) close(f);
     f = -1;
